@@ -15,7 +15,7 @@ sub wanted  {
 
   (my $dir = $File::Find::dir)=~s{examples/}{};
 
-  my $cmd = "strun --purge-cache --root ./examples --story $dir --format production";
+  my $cmd = "cd examples && strun --purge-cache --story $dir --format production";
   (system($cmd) == 0)  or die "$cmd failed";
 
 }
